@@ -1,7 +1,7 @@
 #' @title Coding Sequence Retrieval
 #' @description This function retrieves a fasta-file storing the CDS files of the genome of an organism of interest and stores
 #' this file in the folder '_ncbi_downloads/CDS'.
-#' @param db a character string specifying the database from which the CDS file shall be retrieved: 'refseq'.
+#' @param db a character string specifying the database from which the CDS file shall be retrieved: \code{refseq}.
 #' Right now only the ref seq database is included. Later version of \pkg{biomartr} will also allow
 #' sequence retrieval from additional databases.
 #' @param kingdom a character string specifying the kingdom of the organisms of interest,
@@ -14,8 +14,7 @@
 #' @author Hajk-Georg Drost
 #' @details Internally this function loads the the overview.txt file from NCBI:
 #' 
-#'  refseq: \url{ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/}
-#' 
+#'  refseq: ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/
 #' 
 #' and creates a directory '_ncbi_downloads/CDS' to store
 #' the genome of interest as CDS fasta file for future processing.
@@ -38,36 +37,34 @@
 #' file_path <- file.path("_ncbi_downloads","CDS","Arabidopsis_thaliana_rna.fna.gz")
 #' Ath_CDS <- read_cds(file_path, format = "fasta")
 #' 
-#' 
 #' }
 #' @references 
 #' 
 #' \url{ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq}
-#' 
+#'  
 #' \url{http://www.ncbi.nlm.nih.gov/refseq/about/}
 #' 
-#' @seealso \code{\link{read_cds}}
+#' @seealso \code{\link{getGenome}}, \code{\link{getProteome}}, \code{\link{meta.retrieval}}, \code{\link{read_cds}}
 #' @export
+
 getCDS <- function(db = "refseq", kingdom, organism, path = file.path("_ncbi_downloads","CDS"), delete_corrupt = FALSE){
         
-        if(!is.element(db,c("refseq")))
-                stop("Please select one of the available data bases: 'refseq'")
+        if (!is.element(db,c("refseq")))
+                stop ("Please select one of the available data bases: 'refseq'")
         
-        if(!is.genome.available(organism = organism))
-                stop(paste0("Unfortunately for '",organism,"' no genome is stored on NCBI."))
+        if (!is.genome.available(organism = organism))
+                stop (paste0("Unfortunately for '",organism,"' no genome is stored on NCBI."))
         
-        if(db == "refseq"){
-                if(!file.exists(path)){
+                if (!file.exists(path)){
                         dir.create(path, recursive = TRUE)
                 }
                 
-                subfolders <- c("archaea","bacteria", "fungi", "invertebrate", "plant",
-                                "protozoa", "vertebrate_mammalian", "vertebrate_other")
+                subfolders <- getKingdoms()
                 
-                if(!is.element(kingdom,subfolders))
-                        stop(paste0("Please select a valid kingdom: ",paste0(subfolders,collapse = ", ")))
+                if (!is.element(kingdom,subfolders))
+                        stop (paste0("Please select a valid kingdom: ",paste0(subfolders,collapse = ", ")))
                 
-                url_organisms <- try(RCurl::getURL(paste0("ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/",kingdom,"/"),
+                url_organisms <- try(RCurl::getURL(paste0("ftp://ftp.ncbi.nlm.nih.gov/genomes/",db,"/",kingdom,"/"),
                                                    ftp.use.epsv = FALSE, dirlistonly = TRUE))
                 
                 # replace white space in scientific name with "_"
@@ -79,12 +76,20 @@ getCDS <- function(db = "refseq", kingdom, organism, path = file.path("_ncbi_dow
                 check_organisms <- stringr::str_replace(unlist(check_organisms),"_"," ")
                 check_organisms <- check_organisms[-which(is.element(check_organisms,c("assembly summary.txt", "check_organisms historical.txt")))]
                 
-                if(!is.element(organism,unlist(check_organisms)))
-                        stop("Please choose a valid organism.")
+                if (!is.element(organism,unlist(check_organisms)))
+                        stop ("Please choose a valid organism.")
                 
-                utils::download.file(paste0("ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/",kingdom,"/assembly_summary.txt"), 
+                utils::download.file(paste0("ftp://ftp.ncbi.nlm.nih.gov/genomes/",db,"/",kingdom,"/assembly_summary.txt"), 
                                      destfile = file.path(tempdir(),"assembly_summary.txt"))
-                summary.file <- readr::read_tsv(file.path(tempdir(),"assembly_summary.txt"))
+                summary.file <- readr::read_tsv(file.path(tempdir(),"assembly_summary.txt"), comment = "#")
+                
+                colnames(summary.file) <- c("assembly_accession", "bioproject", "biosample",
+                                            "wgs_master", "refseq_category", "taxid",
+                                            "species_taxid", "organism_name", "infraspecific_name",
+                                            "isolate", "version_status", "assembly_level",
+                                            "release_type", "genome_rep", "seq_rel_date",
+                                            "asm_name", "submitter", "gbrs_paired_asm",
+                                            "paired_asm_comp", "ftp_path", "excluded_from_refseq")
                 
                 organism_name <- refseq_category <- version_status <- NULL
                 query <- dplyr::filter(summary.file, stringr::str_detect(organism_name,organism), 
@@ -97,9 +102,8 @@ getCDS <- function(db = "refseq", kingdom, organism, path = file.path("_ncbi_dow
                 
                 organism <- stringr::str_replace(organism," ","_")
                 
-                download_url <- paste0("ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/",kingdom,"/",
-                                       organism,"/latest_assembly_versions/",paste0(query$`# assembly_accession`,"_",query$asm_name),"/",paste0(query$`# assembly_accession`,"_",query$asm_name,"_rna.fna.gz"))
-                
+                download_url <- paste0("ftp://ftp.ncbi.nlm.nih.gov/genomes/",db,"/",kingdom,"/",
+                                       organism,"/latest_assembly_versions/",paste0(query$assembly_accession,"_",query$asm_name),"/",paste0(query$assembly_accession,"_",query$asm_name,"_rna.fna.gz"))
                 
                 if (nrow(query) == 1){
                         downloader::download(download_url, 
@@ -118,7 +122,6 @@ getCDS <- function(db = "refseq", kingdom, organism, path = file.path("_ncbi_dow
                 } else {
                         
                         warning ("File: ",download_url, " could not be loaded properly...")
-                }
         }
 }
 
