@@ -1,7 +1,7 @@
 #' @title Proteome Retrieval
 #' @description This function retrieves a fasta-file storing the proteome of an organism of interest and stores
 #' the proteome file in the folder '_ncbi_downloads/proteomes'.
-#' @param db a character string specifying the database from which the proteome shall be retrieved: 'refseq'.
+#' @param db a character string specifying the database from which the proteome shall be retrieved: \code{refseq} or \code{genbank}.
 #' Right now only the ref seq database is included. Later version of \pkg{biomartr} will also allow
 #' sequence retrieval from additional databases.
 #' @param kingdom a character string specifying the kingdom of the organisms of interest,
@@ -12,8 +12,9 @@
 #' @author Hajk-Georg Drost
 #' @details Internally this function loads the the overview.txt file from NCBI:
 #' 
-#'  refseq: \url{ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/}
-#' 
+#'  refseq: ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/
+#'  
+#'  genbank: ftp://ftp.ncbi.nlm.nih.gov/genomes/genbank/
 #' 
 #' and creates a directory '_ncbi_downloads/proteomes' to store
 #' the proteome of interest as fasta file for future processing.
@@ -34,38 +35,47 @@
 #' file_path <- file.path("_ncbi_downloads","proteomes","Arabidopsis_thaliana_protein.faa.gz")
 #' Ath_proteome <- read_proteome(file_path, format = "fasta")
 #' 
+#' # download the proteome of Arabidopsis thaliana from genbank
+#' # and store the corresponding proteome file in '_ncbi_downloads/proteomes'
+#' getProteome( db       = "genbank", 
+#'              kingdom  = "plant", 
+#'              organism = "Arabidopsis thaliana", 
+#'              path     = file.path("_ncbi_downloads","proteomes") )
 #' 
+#' 
+#' file_path <- file.path("_ncbi_downloads","proteomes","Arabidopsis_thaliana_protein.faa.gz")
+#' Ath_proteome <- read_proteome(file_path, format = "fasta")
 #' }
 #' @references 
 #' 
 #' \url{ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq}
 #' 
+#' \url{ftp://ftp.ncbi.nlm.nih.gov/genomes/genbank}
+#' 
 #' \url{http://www.ncbi.nlm.nih.gov/refseq/about/}
 #' 
-#' @seealso \code{\link{read_proteome}}
+#' @seealso \code{\link{getGenome}}, \code{\link{getCDS}}, \code{\link{meta.retrieval}}, \code{\link{read_proteome}}
 #' @export
 
 getProteome <- function(db = "refseq", kingdom, organism, path = file.path("_ncbi_downloads","proteomes")){
         
         
-        if(!is.element(db,c("refseq")))
-                stop("Please select one of the available data bases: 'refseq'")
+        if(!is.element(db,c("refseq","genbank")))
+                stop("Please select one of the available data bases: 'refseq' or 'genbank'")
         
         if(!is.genome.available(organism = organism))
                 stop(paste0("Unfortunately for '",organism,"' no genome is stored on NCBI."))
         
-        if(db == "refseq"){
                 if(!file.exists(path)){
                         dir.create(path, recursive = TRUE)
                 }
                 
-                subfolders <- c("archaea","bacteria", "fungi", "invertebrate", "plant",
-                                "protozoa", "vertebrate_mammalian", "vertebrate_other")
+                subfolders <- getKingdoms()
                 
                 if(!is.element(kingdom,subfolders))
                         stop(paste0("Please select a valid kingdom: ",paste0(subfolders,collapse = ", ")))
                 
-                url_organisms <- try(RCurl::getURL(paste0("ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/",kingdom,"/"),
+                url_organisms <- try(RCurl::getURL(paste0("ftp://ftp.ncbi.nlm.nih.gov/genomes/",db,"/",kingdom,"/"),
                                                    ftp.use.epsv = FALSE, dirlistonly = TRUE))
                 
                 # replace white space in scientific name with "_"
@@ -80,9 +90,17 @@ getProteome <- function(db = "refseq", kingdom, organism, path = file.path("_ncb
                 if(!is.element(organism,unlist(check_organisms)))
                         stop("Please choose a valid organism.")
                 
-                utils::download.file(paste0("ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/",kingdom,"/assembly_summary.txt"), 
+                utils::download.file(paste0("ftp://ftp.ncbi.nlm.nih.gov/genomes/",db,"/",kingdom,"/assembly_summary.txt"), 
                                      destfile = file.path(tempdir(),"assembly_summary.txt"))
-                summary.file <- readr::read_tsv(file.path(tempdir(),"assembly_summary.txt"))
+                summary.file <- readr::read_tsv(file.path(tempdir(),"assembly_summary.txt"), comment = "#")
+                
+                colnames(summary.file) <- c("assembly_accession", "bioproject", "biosample",
+                                            "wgs_master", "refseq_category", "taxid",
+                                            "species_taxid", "organism_name", "infraspecific_name",
+                                            "isolate", "version_status", "assembly_level",
+                                            "release_type", "genome_rep", "seq_rel_date",
+                                            "asm_name", "submitter", "gbrs_paired_asm",
+                                            "paired_asm_comp", "ftp_path", "excluded_from_refseq")
                 
                 organism_name <- refseq_category <- version_status <- NULL
                 query <- dplyr::filter(summary.file, stringr::str_detect(organism_name,organism), 
@@ -95,8 +113,8 @@ getProteome <- function(db = "refseq", kingdom, organism, path = file.path("_ncb
                 
                 organism <- stringr::str_replace(organism," ","_")
                 
-                download_url <- paste0("ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/",kingdom,"/",
-                                       organism,"/latest_assembly_versions/",paste0(query$`# assembly_accession`,"_",query$asm_name),"/",paste0(query$`# assembly_accession`,"_",query$asm_name,"_protein.faa.gz"))
+                download_url <- paste0("ftp://ftp.ncbi.nlm.nih.gov/genomes/",db,"/",kingdom,"/",
+                                       organism,"/latest_assembly_versions/",paste0(query$assembly_accession,"_",query$asm_name),"/",paste0(query$assembly_accession,"_",query$asm_name,"_protein.faa.gz"))
                 
                 if (nrow(query) == 1){
                         downloader::download(download_url, 
@@ -115,7 +133,6 @@ getProteome <- function(db = "refseq", kingdom, organism, path = file.path("_ncb
                 } else {
                         
                         warning ("File: ",download_url, " could not be loaded properly...")
-                }
         }
 }
 
