@@ -11,10 +11,10 @@ test_that("The getAttributes() interface works properly..",{
         skip_on_cran()
         
         marts <- getMarts()[ , "mart"]
-        plant_mart <- which(stringr::str_match(marts, "plants_mart_") != "NA")
+        ensemb_mart <- which(stringr::str_match(marts, "ENSEMBL_MART_ENSEMBL") != "NA")
         
-        attrib <- getAttributes(mart = as.character(marts[plant_mart]), dataset = "athaliana_eg_gene")
+        attrib <- getAttributes(mart = as.character(marts[ensemb_mart]), dataset = "hsapiens_gene_ensembl")
         
         expect_true(equal_lists(as.list(attrib[1 , ]), list(name = "ensembl_gene_id",
-                                                            description = "Gene stable ID")))
+                                                            description = "Ensembl Gene ID")))
 })
\ No newline at end of file
